@@ -1,5 +1,5 @@
 /* done.c --- Exit point for libgsasl.
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -13,9 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
- * License along with GNU SASL Library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License License along with GNU SASL Library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -41,7 +42,6 @@ gsasl_done (Gsasl * ctx)
     if (ctx->client_mechs[i].client.done)
       ctx->client_mechs[i].client.done (ctx);
 
-  if (ctx->client_mechs)
     free (ctx->client_mechs);
 #endif
 
@@ -50,8 +50,7 @@ gsasl_done (Gsasl * ctx)
     if (ctx->server_mechs[i].server.done)
       ctx->server_mechs[i].server.done (ctx);
 
-  if (ctx->server_mechs)
-    free (ctx->server_mechs);
+  free (ctx->server_mechs);
 #endif
 
   free (ctx);
